@@ -7,8 +7,6 @@ from collections import defaultdict
 import csv
 import json
 
-import six
-
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.db.models import F
@@ -91,7 +89,7 @@ class CsvWriter:
         """
         self.writers = {
             key: csv.writer(file_handle)
-            for key, file_handle in six.iteritems(output_streams)
+            for key, file_handle in output_streams.items()
             if key in self.MODELS
         }
         self._progress_callback = progress_callback
@@ -187,7 +185,7 @@ class CsvWriter:
         """
         Write the headers (first row) for each output stream.
         """
-        for name, writer in six.iteritems(self.writers):
+        for name, writer in self.writers.items():
             writer.writerow(self.HEADERS[name])
 
     def _write_submission_to_csv(self, submission_uuid):
@@ -283,7 +281,7 @@ class CsvWriter:
 
         """
         options_string = ",".join([
-            six.text_type(option.id) for option in assessment_feedback.options.all()
+            str(option.id) for option in assessment_feedback.options.all()
         ])
 
         self._write_unicode('assessment_feedback', [
@@ -324,10 +322,7 @@ class CsvWriter:
         """
         writer = self.writers.get(output_name)
         if writer is not None:
-            if six.PY2:
-                encoded_row = [six.text_type(field).encode('utf-8') for field in row]
-            else:
-                encoded_row = [six.text_type(field) for field in row]
+            encoded_row = [str(field) for field in row]
             writer.writerow(encoded_row)
 
     def _use_read_replica(self, queryset):
@@ -428,6 +423,42 @@ class OraAggregateData:
 
         return cls._map_anonymized_ids_to_usernames(student_ids + list(scorer_ids))
 
+    @classmethod
+    def _map_block_usage_keys_to_display_names(cls, course_id):
+        """
+        Fetches all course blocks and build mapping between block usage key
+        string and block display name for those ones, whoose category is equal
+        to ``openassessment``.
+
+        Args:
+            course_id (string or CourseLocator instance) - id of course
+            resourse
+        Returns:
+            dictionary, that contains mapping between block usage
+            keys (locations) and block display names.
+        """
+        # pylint: disable=import-error
+
+        from lms.djangoapps.course_blocks.api import get_course_blocks
+        from openedx.core.djangoapps.content.block_structure.transformers import BlockStructureTransformers
+
+        from xmodule.modulestore.django import modulestore
+
+        store = modulestore()
+        course_usage_key = store.make_course_usage_key(course_id)
+
+        # Passing an empty block structure transformer here to avoid user access checks
+        blocks = get_course_blocks(None, course_usage_key, BlockStructureTransformers())
+
+        block_display_name_map = {}
+
+        for block_key in blocks:
+            block_type = blocks.get_xblock_field(block_key, 'category')
+            if block_type == 'openassessment':
+                block_display_name_map[str(block_key)] = blocks.get_xblock_field(block_key, 'display_name')
+
+        return block_display_name_map
+
     @classmethod
     def _build_assessments_cell(cls, assessments, usernames_map):
         """
@@ -528,6 +559,7 @@ class OraAggregateData:
             if usernames_enabled
             else {}
         )
+        block_display_names_map = cls._map_block_usage_keys_to_display_names(course_id)
 
         rows = []
         for student_item, submission, score in all_submission_information:
@@ -549,8 +581,12 @@ class OraAggregateData:
                 else []
             )
 
+            problem_name = block_display_names_map.get(student_item['item_id'])
+
             row = [
                 submission['uuid'],
+                student_item['item_id'],
+                problem_name,
                 submission['student_item'],
             ] + row_username_cell + [
                 student_item['student_id'],
@@ -575,6 +611,8 @@ class OraAggregateData:
 
         header = [
             'Submission ID',
+            'Location',
+            'Problem Name',
             'Item ID'
         ] + header_username_cell + [
             'Anonymized Student ID',
